@@ -179,8 +179,7 @@ public class TestConversion extends TestFmwk {
         logln("TestFromUnicode[" + caseNr + "] " + cc.charset + " ");
         logln("Unicode:   " + cc.unicode);
         logln("Bytes:    " + printbytes(cc.bytes, cc.bytes.limit()));
-        ByteBuffer c = ByteBuffer.wrap(cc.cbopt.getBytes());
-        logln("Callback: " + printbytes(c, c.limit()) + " (" + cc.cbopt + ")");
+        logln("Callback: " + cc.cbopt);
         logln("...............................................");
 
         // process the retrieved test data case
@@ -470,8 +469,7 @@ public class TestConversion extends TestFmwk {
         logln("TestToUnicode[" + caseNr + "] " + cc.charset + " ");
         logln("Unicode:   " + hex(cc.unicode));
         logln("Bytes:    " + printbytes(cc.bytes, cc.bytes.limit()));
-        ByteBuffer c = ByteBuffer.wrap(cc.cbopt.getBytes());
-        logln("Callback: " + printbytes(c, c.limit()) + " (" + cc.cbopt + ")");
+        logln("Callback: " + cc.cbopt);
         logln("...............................................");
 
         // process the retrieved test data case
@@ -917,11 +915,21 @@ public class TestConversion extends TestFmwk {
 
                     //checking for converter that are not supported at this point
                     try{
-                        if(charset==null ||
-                                charset.name()=="BOCU-1" ||charset.name()== "SCSU"|| charset.name()=="lmbcs1" || charset.name()== "lmbcs2" ||
-                                charset.name()== "lmbcs3" || charset.name()== "lmbcs4" || charset.name()=="lmbcs5" || charset.name()=="lmbcs6" ||
-                                charset.name()== "lmbcs8" || charset.name()=="lmbcs11" || charset.name()=="lmbcs16" || charset.name()=="lmbcs17" ||
-                                charset.name()=="lmbcs18"|| charset.name()=="lmbcs19"){
+                        if(charset==null
+                                || charset.name().equals("BOCU-1")
+                                || charset.name().equals("SCSU")
+                                || charset.name().equals("lmbcs1")
+                                || charset.name().equals("lmbcs2")
+                                || charset.name().equals("lmbcs3")
+                                || charset.name().equals("lmbcs4")
+                                || charset.name().equals("lmbcs5")
+                                || charset.name().equals("lmbcs6")
+                                || charset.name().equals("lmbcs8")
+                                || charset.name().equals("lmbcs11")
+                                || charset.name().equals("lmbcs16")
+                                || charset.name().equals("lmbcs17")
+                                || charset.name().equals("lmbcs18")
+                                || charset.name().equals("lmbcs19")) {
                             logln("Converter not supported at this point :" + cc.charset);
                             return;
                         }
@@ -947,7 +955,7 @@ public class TestConversion extends TestFmwk {
                     //are there items that must be in unicodeset but are not?
                     (diffset = mapset).removeAll(unicodeset);
                     if(!diffset.isEmpty()){
-                        StringBuffer s = new StringBuffer(diffset.toPattern(true));
+                        StringBuilder s = new StringBuilder(diffset.toPattern(true));
                         if(s.length()>100){
                             s.replace(0, 0x7fffffff, ellipsis);
                         }
@@ -957,7 +965,7 @@ public class TestConversion extends TestFmwk {
                     //are the items that must not be in unicodeset but are?
                     (diffset=mapnotset).retainAll(unicodeset);
                     if(!diffset.isEmpty()){
-                        StringBuffer s = new StringBuffer(diffset.toPattern(true));
+                        StringBuilder s = new StringBuilder(diffset.toPattern(true));
                         if(s.length()>100){
                             s.replace(0, 0x7fffffff, ellipsis);
                         }
