@@ -86,7 +86,7 @@ public class IntlTestDecimalFormatAPIC extends CoreTestFmwk {
 
         logln("Testing clone() and equality operators");
 
-        Format clone = (Format) def.clone();
+        Format clone = def.clone();
         if (!def.equals(clone)) {
             errln("ERROR: Clone() failed");
         }
