@@ -146,8 +146,6 @@ public class TimeZoneFormatTest extends CoreTestFmwk {
         for (int locidx = 0; locidx < LOCALES.length; locidx++) {
             logln("Locale: " + LOCALES[locidx].toString());
 
-            String localGMTString = TimeZoneFormat.getInstance(LOCALES[locidx]).formatOffsetLocalizedGMT(0);
-
             for (int patidx = 0; patidx < PATTERNS.length; patidx++) {
                 logln("    pattern: " + PATTERNS[patidx]);
                 SimpleDateFormat sdf = new SimpleDateFormat(PATTERNS[patidx], LOCALES[locidx]);
@@ -258,7 +256,7 @@ public class TimeZoneFormatTest extends CoreTestFmwk {
                                 isOffsetFormat = (numDigits > 0);
                             }
 
-                            if (isOffsetFormat || tzstr.equals(localGMTString)) {
+                            if (isOffsetFormat) {
                                 // Localized GMT or ISO: total offset (raw + dst) must be preserved.
                                 int inOffset = inOffsets[0] + inOffsets[1];
                                 int outOffset = outOffsets[0] + outOffsets[1];
@@ -402,7 +400,14 @@ public class TimeZoneFormatTest extends CoreTestFmwk {
                 }
 
                 for (String id : ids) {
-                    if (PATTERNS[patidx].equals("V")) {
+					// NOTE: This test only fails in the exhaustive tests.  If you take out this check,
+					// make sure you run the exhaustive tests!
+                    if (logKnownIssue("CLDR-18924", "Time round trip issues for Pacific/Apia in various locales")
+                            && id.equals("Pacific/Apia")) {
+                        continue;
+                    }
+
+                 	if (PATTERNS[patidx].equals("V")) {
                         // Some zones do not have short ID assigned, such as Asia/Riyadh87.
                         // The time roundtrip will fail for such zones with pattern "V" (short zone ID).
                         // This is expected behavior.
@@ -419,12 +424,6 @@ public class TimeZoneFormatTest extends CoreTestFmwk {
                         }
                     }
 
-                    if ((id.equals("Pacific/Apia") || id.equals("Pacific/Midway") || id.equals("Pacific/Pago_Pago"))
-                            && PATTERNS[patidx].equals("vvvv")
-                            && logKnownIssue("11052", "Ambiguous zone name - Samoa Time")) {
-                        continue;
-                    }
-
                     BasicTimeZone btz = (BasicTimeZone)TimeZone.getTimeZone(id, TimeZone.TIMEZONE_ICU);
                     TimeZone tz = TimeZone.getTimeZone(id);
                     sdf.setTimeZone(tz);
