@@ -277,7 +277,7 @@ public class UnitsTest {
                 new TestData("millimeter", "meter", UnitsConverter.Convertibility.CONVERTIBLE),
                 new TestData("yard", "meter", UnitsConverter.Convertibility.CONVERTIBLE),
                 new TestData("ounce-troy", "kilogram", UnitsConverter.Convertibility.CONVERTIBLE),
-                new TestData("percent", "portion", UnitsConverter.Convertibility.CONVERTIBLE),
+                new TestData("percent", "part", UnitsConverter.Convertibility.CONVERTIBLE),
                 new TestData("ofhg", "kilogram-per-square-meter-square-second", UnitsConverter.Convertibility.CONVERTIBLE),
                 new TestData("second-per-meter", "meter-per-second", UnitsConverter.Convertibility.RECIPROCAL),
                 new TestData("mile-per-hour", "meter-per-second", UnitsConverter.Convertibility.CONVERTIBLE),
@@ -512,16 +512,16 @@ public class UnitsTest {
                 new TestData("meter-per-10", "foot", 1.0, 0.328084),
                 new TestData("meter", "foot-per-10", 1.0, 32.8084),
                 new TestData("meter", "foot-per-100", 1.0, 328.084),
-                new TestData("portion", "portion-per-1000", 1.0, 1000),
-                new TestData("portion", "portion-per-10000", 1.0, 10000),
-                new TestData("portion", "portion-per-100000", 1.0, 100000),
-                new TestData("portion", "portion-per-1000000", 1.0, 1000000),
-                new TestData("portion-per-10", "portion", 1.0, 0.1),
-                new TestData("portion-per-100", "portion", 1.0, 0.01),
-                new TestData("portion-per-1000", "portion", 1.0, 0.001),
-                new TestData("portion-per-10000", "portion", 1.0, 0.0001),
-                new TestData("portion-per-100000", "portion", 1.0, 0.00001),
-                new TestData("portion-per-1000000", "portion", 1.0, 0.000001),
+                new TestData("part", "part-per-1000", 1.0, 1000),
+                new TestData("part", "part-per-10000", 1.0, 10000),
+                new TestData("part", "part-per-100000", 1.0, 100000),
+                new TestData("part", "part-per-1000000", 1.0, 1000000),
+                new TestData("part-per-10", "part", 1.0, 0.1),
+                new TestData("part-per-100", "part", 1.0, 0.01),
+                new TestData("part-per-1000", "part", 1.0, 0.001),
+                new TestData("part-per-10000", "part", 1.0, 0.0001),
+                new TestData("part-per-100000", "part", 1.0, 0.00001),
+                new TestData("part-per-1000000", "part", 1.0, 0.000001),
                 new TestData("mile-per-hour", "meter-per-second", 1.0, 0.44704),
                 new TestData("mile-per-100-hour", "meter-per-100-second", 1.0, 0.44704),
                 new TestData("mile-per-hour", "meter-per-100-second", 1.0, 44.704),
@@ -590,9 +590,8 @@ public class UnitsTest {
             }
         }
 
-        String codePage = "UTF-8";
         ArrayList<TestCase> tests = new ArrayList<>();
-        try (BufferedReader f = TestUtil.getDataReader("cldr/units/unitsTest.txt", codePage)) {
+        try (BufferedReader f = TestUtil.getUtf8DataReader("cldr/units/unitsTest.txt")) {
             while (true) {
                 String line = f.readLine();
                 if (line == null) break;
@@ -713,10 +712,9 @@ public class UnitsTest {
         }
 
         // Read Test data from the unitPreferencesTest
-        String codePage = "UTF-8";
         ArrayList<TestCase> tests = new ArrayList<>();
 
-        try (BufferedReader f = TestUtil.getDataReader("cldr/units/unitPreferencesTest.txt", codePage)) {
+        try (BufferedReader f = TestUtil.getUtf8DataReader("cldr/units/unitPreferencesTest.txt")) {
             while (true) {
                 String line = f.readLine();
                 if (line == null) break;
@@ -855,8 +853,8 @@ public class UnitsTest {
         TestCase[] testCases = {
                 new TestCase("meter-per-second", 100, Complexity.COMPOUND),
                 new TestCase("meter-per-100-second", 0, Complexity.COMPOUND),
-                new TestCase("portion", 100, Complexity.COMPOUND),
-                new TestCase("portion-per-100", 0, Complexity.SINGLE),
+                new TestCase("part", 100, Complexity.COMPOUND),
+                new TestCase("part-per-100", 0, Complexity.SINGLE),
         };
 
         for (TestCase testCase : testCases) {
