@@ -15,8 +15,8 @@ import org.junit.runners.JUnit4;
 
 import com.ibm.icu.dev.test.CoreTestFmwk;
 import com.ibm.icu.message2.FormattedPlaceholder;
-import com.ibm.icu.message2.Formatter;
-import com.ibm.icu.message2.FormatterFactory;
+import com.ibm.icu.message2.Function;
+import com.ibm.icu.message2.FunctionFactory;
 import com.ibm.icu.message2.MFFunctionRegistry;
 import com.ibm.icu.message2.MessageFormatter;
 import com.ibm.icu.number.FormattedNumber;
@@ -57,37 +57,12 @@ public class MessageFormat2Test extends CoreTestFmwk {
                 mf2.formatToString(Args.of("exp", expiration)));
 
         mf2 = MessageFormatter.builder()
-                .setPattern("Your card expires on {$exp :datetime year=numeric month=short day=numeric weekday=short}!")
+                .setPattern("Your card expires on {$exp :date fields=year-month-day-weekday length=medium}!")
                 .build();
         assertEquals("date format",
                 "Your card expires on Thu, Oct 27, 2022!",
                 mf2.formatToString(Args.of("exp", expiration)));
 
-        mf2 = MessageFormatter.builder()
-                .setPattern("Your card expires on {$exp :datetime dateStyle=full}!")
-                .build();
-        assertEquals("date format",
-                "Your card expires on Thursday, October 27, 2022!",
-                mf2.formatToString(Args.of("exp", expiration)));
-        mf2 = MessageFormatter.builder()
-                .setPattern("Your card expires on {$exp :datetime dateStyle=long}!")
-                .build();
-        assertEquals("date format",
-                "Your card expires on October 27, 2022!",
-                mf2.formatToString(Args.of("exp", expiration)));
-        mf2 = MessageFormatter.builder()
-                .setPattern("Your card expires on {$exp :date style=medium}!")
-                .build();
-        assertEquals("date format",
-                "Your card expires on Oct 27, 2022!",
-                mf2.formatToString(Args.of("exp", expiration)));
-        mf2 = MessageFormatter.builder()
-                .setPattern("Your card expires on {$exp :datetime dateStyle=short}!")
-                .build();
-        assertEquals("date format",
-                "Your card expires on 10/27/22!",
-                mf2.formatToString(Args.of("exp", expiration)));
-
         Calendar cal = new GregorianCalendar(2022, Calendar.OCTOBER, 27);
         mf2 = MessageFormatter.builder()
                 .setPattern("Your card expires on {$exp :datetime icu:skeleton=yMMMdE}!")
@@ -101,10 +76,10 @@ public class MessageFormat2Test extends CoreTestFmwk {
                 .setPattern("Your card expires on {$exp}!")
                 .build();
         assertEquals("date format",
-                "Your card expires on 10/27/22, 12:00\u202FAM!",
+                "Your card expires on Thu, Oct 27, 2022, 12:00\u202FAM!",
                 mf2.formatToString(Args.of("exp", expiration)));
         assertEquals("date format",
-                "Your card expires on 10/27/22, 12:00\u202FAM!",
+                "Your card expires on Thu, Oct 27, 2022, 12:00\u202FAM!",
                 mf2.formatToString(Args.of("exp", cal)));
 
         // Implied function based on type of the object to format
@@ -124,6 +99,68 @@ public class MessageFormat2Test extends CoreTestFmwk {
         assertEquals("date format",
                 "Your card expires on Wed, Oct 27, 1479!",
                 mf2.formatToString(Args.of("exp", calNotRegistered)));
+        
+        // Test the overrides
+        cal = new GregorianCalendar(2025, Calendar.SEPTEMBER, 23, 19, 42, 51);
+
+        mf2 = MessageFormatter.builder()
+                .setPattern("Date time: {$exp :datetime"
+                        + " dateFields=year-month-day-weekday dateLength=medium"
+                        + " timePrecision=minute}")
+                .setLocale(Locale.US)
+                .build();
+        assertEquals("date format",
+                "Date time: Tue, Sep 23, 2025, 7:42\u202FPM",
+                mf2.formatToString(Args.of("exp", cal)));
+        // Force 24h clock
+        mf2 = MessageFormatter.builder()
+                .setPattern("Date time: {$exp :datetime"
+                        + " dateFields=year-month-day-weekday dateLength=medium"
+                        + " timePrecision=minute hour12=false}")
+                .setLocale(Locale.US)
+                .build();
+        assertEquals("date format",
+                "Date time: Tue, Sep 23, 2025, 19:42",
+                mf2.formatToString(Args.of("exp", cal)));
+        // Force 12h clock
+        mf2 = MessageFormatter.builder()
+                .setPattern("Date time: {$exp :datetime"
+                        + " dateFields=year-month-day-weekday dateLength=medium"
+                        + " timePrecision=minute hour12=true}")
+                .setLocale(Locale.FRANCE)
+                .build();
+        assertEquals("date format",
+                "Date time: mar. 23 sept. 2025, 7:42\u202FPM",
+                mf2.formatToString(Args.of("exp", cal)));
+        // Force timezone
+        mf2 = MessageFormatter.builder()
+                .setPattern("Date time: {$exp :datetime"
+                        + " dateFields=year-month-day-weekday dateLength=medium"
+                        + " timePrecision=minute timeZoneStyle=long timeZone=|America/New_York|}")
+                .setLocale(Locale.US)
+                .build();
+        assertEquals("date format",
+                "Date time: Tue, Sep 23, 2025, 10:42\u202fPM Eastern Daylight Time",
+                mf2.formatToString(Args.of("exp", cal.getTime())));
+        mf2 = MessageFormatter.builder()
+                .setPattern("Date time: {$exp :datetime"
+                        + " dateFields=year-month-day-weekday dateLength=medium"
+                        + " timePrecision=minute timeZoneStyle=short timeZone=|Pacific/Honolulu|}")
+                .setLocale(Locale.US)
+                .build();
+        assertEquals("date format",
+                "Date time: Tue, Sep 23, 2025, 4:42\u202fPM HST",
+                mf2.formatToString(Args.of("exp", cal.getTime())));
+        // Force calendar
+        mf2 = MessageFormatter.builder()
+                .setPattern("Date time: {$exp :datetime"
+                        + " dateFields=year-month-day dateLength=medium"
+                        + " timePrecision=minute calendar=islamic}")
+                .setLocale(Locale.US)
+                .build();
+        assertEquals("date format",
+                "Date time: Rab. II 2, 1447 AH, 7:42\u202FPM",
+                mf2.formatToString(Args.of("exp", cal)));
     }
 
     @Test
@@ -185,14 +222,14 @@ public class MessageFormat2Test extends CoreTestFmwk {
                 mf2.formatToString(Args.of("place", 15)));
     }
 
-    static class TemperatureFormatterFactory implements FormatterFactory {
+    static class TemperatureFunctionFactory implements FunctionFactory {
         int constructCount = 0;
         int formatCount = 0;
         int fFormatterCount = 0;
         int cFormatterCount = 0;
 
         @Override
-        public Formatter createFormatter(Locale locale, Map<String, Object> fixedOptions) {
+        public Function create(Locale locale, Map<String, Object> fixedOptions) {
             // Check that the formatter can only see the fixed options
             Assert.assertTrue(fixedOptions.containsKey("icu:skeleton"));
             Assert.assertFalse(fixedOptions.containsKey("icu:unit"));
@@ -202,19 +239,19 @@ public class MessageFormat2Test extends CoreTestFmwk {
                     ? NumberFormatter.forSkeleton(valSkeleton.toString()).locale(locale)
                     : NumberFormatter.withLocale(locale);
 
-            return new TemperatureFormatterImpl(nf, this);
+            return new TemperatureFunctionImpl(nf, this);
         }
 
-        private static class TemperatureFormatterImpl implements Formatter {
-            private final TemperatureFormatterFactory formatterFactory;
+        private static class TemperatureFunctionImpl implements Function {
+            private final TemperatureFunctionFactory functionFactory;
             private final LocalizedNumberFormatter nf;
-            private final Map<String, LocalizedNumberFormatter> cachedFormatters =
+            private final Map<String, LocalizedNumberFormatter> cachedFunctions =
                     new HashMap<>();
 
-            TemperatureFormatterImpl(LocalizedNumberFormatter nf, TemperatureFormatterFactory formatterFactory) {
+            TemperatureFunctionImpl(LocalizedNumberFormatter nf, TemperatureFunctionFactory functionFactory) {
                 this.nf = nf;
-                this.formatterFactory = formatterFactory;
-                this.formatterFactory.constructCount++;
+                this.functionFactory = functionFactory;
+                this.functionFactory.constructCount++;
             }
 
             @Override
@@ -227,25 +264,25 @@ public class MessageFormat2Test extends CoreTestFmwk {
                 // Check that the formatter can only see the variable options
                 Assert.assertFalse(variableOptions.containsKey("skeleton"));
                 Assert.assertTrue(variableOptions.containsKey("unit"));
-                this.formatterFactory.formatCount++;
+                this.functionFactory.formatCount++;
 
                 String unit = variableOptions.get("unit").toString();
-                LocalizedNumberFormatter realNf = cachedFormatters.get(unit);
+                LocalizedNumberFormatter realNf = cachedFunctions.get(unit);
                 if (realNf == null) {
                     switch (variableOptions.get("unit").toString()) {
                         case "C":
-                            formatterFactory.cFormatterCount++;
+                            functionFactory.cFormatterCount++;
                             realNf = nf.unit(MeasureUnit.CELSIUS);
                             break;
                         case "F":
-                            formatterFactory.fFormatterCount++;
+                            functionFactory.fFormatterCount++;
                             realNf = nf.unit(MeasureUnit.FAHRENHEIT);
                             break;
                         default:
                             realNf = nf;
                             break;
                     }
-                    cachedFormatters.put(unit, realNf);
+                    cachedFunctions.put(unit, realNf);
                 }
 
                 FormattedNumber result;
@@ -267,12 +304,12 @@ public class MessageFormat2Test extends CoreTestFmwk {
 
     @Test
     // Due to the many changes in how the variable resolution is done,
-    // it is now not possible to caching the formatters.
+    // it is now not possible to cache the formatters.
     // Might be able to bring it back, but for now it is off.
     public void testFormatterIsCreatedOnce() {
-        TemperatureFormatterFactory counter = new TemperatureFormatterFactory();
+        TemperatureFunctionFactory counter = new TemperatureFunctionFactory();
         MFFunctionRegistry registry = MFFunctionRegistry.builder()
-                .setFormatter("temp", counter)
+                .setFunction("temp", counter)
                 .build();
         String message = "Testing {$count :temp unit=$unit icu:skeleton=|.00/w|}.";
         MessageFormatter mf2 = MessageFormatter.builder()
@@ -334,41 +371,13 @@ public class MessageFormat2Test extends CoreTestFmwk {
     @Test
     public void testPluralWithOffset() {
         String message = ""
-                + ".input {$count :number icu:offset=2}\n"
-                + ".match $count\n"
-                + " 1   {{Anna}}\n"
-                + " 2   {{Anna and Bob}}\n"
-                + " one {{Anna, Bob, and {$count :number icu:offset=2} other guest}}\n"
-                + " *   {{Anna, Bob, and {$count :number icu:offset=2} other guests}}";
-        MessageFormatter mf2 = MessageFormatter.builder()
-                .setPattern(message)
-                .build();
-        assertEquals("plural with offset",
-                "Anna",
-                mf2.formatToString(Args.of("count", 1)));
-        assertEquals("plural with offset",
-                "Anna and Bob",
-                mf2.formatToString(Args.of("count", 2)));
-        assertEquals("plural with offset",
-                "Anna, Bob, and 1 other guest",
-                mf2.formatToString(Args.of("count", 3)));
-        assertEquals("plural with offset",
-                "Anna, Bob, and 2 other guests",
-                mf2.formatToString(Args.of("count", 4)));
-        assertEquals("plural with offset",
-                "Anna, Bob, and 10 other guests",
-                mf2.formatToString(Args.of("count", 12)));
-    }
-
-    @Test
-    public void testPluralWithOffsetAndLocalVar() {
-        String message = ""
-                + ".local $foo = {$count :number icu:offset=2}"
-                + ".match $foo\n" // should "inherit" the offset
-                + " 1   {{Anna}}\n"
-                + " 2   {{Anna and Bob}}\n"
-                + " one {{Anna, Bob, and {$foo} other guest}}\n"
-                + " *   {{Anna, Bob, and {$foo} other guests}}";
+                + ".input {$count :number}\n"
+                + ".local $offsetCount = {$count :offset subtract=2}\n"
+                + ".match $count $offsetCount\n"
+                + " 1 *  {{Anna}}\n"
+                + " 2 *  {{Anna and Bob}}\n"
+                + " * one {{Anna, Bob, and {$offsetCount} other guest}}\n"
+                + " * *   {{Anna, Bob, and {$offsetCount} other guests}}";
         MessageFormatter mf2 = MessageFormatter.builder()
                 .setPattern(message)
                 .build();
@@ -450,12 +459,13 @@ public class MessageFormat2Test extends CoreTestFmwk {
     @Test
     public void testVariableOptionsInSelector() {
         String messageVar = ""
-                + ".input {$count :number icu:offset=$delta}\n"
-                + ".match $count\n"
-                + " 1   {{A}}\n"
-                + " 2   {{A and B}}\n"
-                + " one {{A, B, and {$count :number icu:offset=$delta} more character}}\n"
-                + " *   {{A, B, and {$count :number icu:offset=$delta} more characters}}";
+                + ".input {$count :number}\n"
+                + ".local $offsetCount = {$count :offset subtract=$delta}\n"
+                + ".match $count $offsetCount\n"
+                + " 1 *  {{A}}\n"
+                + " 2 *  {{A and B}}\n"
+                + " * one {{A, B, and {$offsetCount} more character}}\n"
+                + " * *   {{A, B, and {$offsetCount} more characters}}";
         MessageFormatter mfVar = MessageFormatter.builder()
                 .setPattern(messageVar)
                 .build();
@@ -469,11 +479,12 @@ public class MessageFormat2Test extends CoreTestFmwk {
                 mfVar.formatToString(Args.of("count", 7, "delta", 2)));
 
         String messageVar2 = ""
-                + ".input {$count :number icu:offset=$delta}\n"
-                + ".match $count\n"
-                + " 1 {{Exactly 1}}\n"
-                + " 2 {{Exactly 2}}\n"
-                + " * {{Count = {$count :number icu:offset=$delta} and delta={$delta}.}}";
+                + ".input {$count :number}\n"
+                + ".local $offsetCount = {$count :offset subtract=$delta}\n"
+                + ".match $count $offsetCount\n"
+                + " 1 * {{Exactly 1}}\n"
+                + " 2 * {{Exactly 2}}\n"
+                + " * * {{Count = {$count :number icu:offset=$delta} and delta={$delta}.}}";
         MessageFormatter mfVar2 = MessageFormatter.builder()
                 .setPattern(messageVar2)
                 .build();
@@ -509,12 +520,13 @@ public class MessageFormat2Test extends CoreTestFmwk {
     @Test
     public void testVariableOptionsInSelectorWithLocalVar() {
         String messageFix = ""
-                + ".local $offCount = {$count :number icu:offset=2}"
-                + ".match $offCount\n"
-                + " 1   {{A}}\n"
-                + " 2   {{A and B}}\n"
-                + " one {{A, B, and {$offCount} more character}}\n"
-                + " *   {{A, B, and {$offCount} more characters}}";
+                + ".input {$count :integer}"
+                + ".local $offCount = {$count :offset subtract=2}"
+                + ".match $count $offCount\n"
+                + " 1 *  {{A}}\n"
+                + " 2 *  {{A and B}}\n"
+                + " * one {{A, B, and {$offCount} more character}}\n"
+                + " * *   {{A, B, and {$offCount} more characters}}";
         MessageFormatter mfFix = MessageFormatter.builder()
                 .setPattern(messageFix)
                 .build();
@@ -524,12 +536,13 @@ public class MessageFormat2Test extends CoreTestFmwk {
         assertEquals("test local vars loop", "A, B, and 5 more characters", mfFix.formatToString(Args.of("count", 7)));
 
         String messageVar = ""
-                + ".local $offCount = {$count :number icu:offset=$delta}"
-                + ".match $offCount\n"
-                + " 1   {{A}}\n"
-                + " 2   {{A and B}}\n"
-                + " one {{A, B, and {$offCount} more character}}\n"
-                + " *   {{A, B, and {$offCount} more characters}}";
+                + ".input {$count :number}"
+                + ".local $offCount = {$count :offset subtract=$delta}"
+                + ".match $count $offCount\n"
+                + " 1 *  {{A}}\n"
+                + " 2 *  {{A and B}}\n"
+                + " * one {{A, B, and {$offCount} more character}}\n"
+                + " * *   {{A, B, and {$offCount} more characters}}";
         MessageFormatter mfVar = MessageFormatter.builder()
                 .setPattern(messageVar)
                 .build();
@@ -543,11 +556,12 @@ public class MessageFormat2Test extends CoreTestFmwk {
                 mfVar.formatToString(Args.of("count", 7, "delta", 2)));
 
         String messageVar2 = ""
-                + ".local $offCount = {$count :number icu:offset=$delta}"
-                + ".match $offCount\n"
-                + " 1 {{Exactly 1}}\n"
-                + " 2 {{Exactly 2}}\n"
-                + " * {{Count = {$count}, OffCount = {$offCount}, and delta={$delta}.}}";
+                + ".input {$count :number}"
+                + ".local $offCount = {$count :offset subtract=$delta}"
+                + ".match $count $offCount\n"
+                + " 1 * {{Exactly 1}}\n"
+                + " 2 * {{Exactly 2}}\n"
+                + " * * {{Count = {$count}, OffCount = {$offCount}, and delta={$delta}.}}";
         MessageFormatter mfVar2 = MessageFormatter.builder()
                 .setPattern(messageVar2)
                 .build();
@@ -586,7 +600,7 @@ public class MessageFormat2Test extends CoreTestFmwk {
         String result;
         Map<String, Object> messageArguments = new HashMap<>();
 
-        // Check that constructing the formatter fails
+        // Check that constructing the function fails
         // if there's a syntax error
         String pattern = "{{}";
         MessageFormatter.Builder mfBuilder = MessageFormatter.builder();
