@@ -16,6 +16,7 @@ import java.util.Arrays;
 import java.util.Locale;
 import java.util.Properties;
 import java.util.Random;
+import java.util.StringJoiner;
 import java.util.TimeZone;
 
 import org.junit.After;
@@ -117,6 +118,7 @@ abstract public class TestFmwk extends AbstractTestLog {
     public final static void testClassTeardown() {
         getParams().knownIssues.printKnownIssues(new UnicodeKnownIssues.Consumer<String>() {
             // TODO: make this a Lambda once JDK 1.8 ships
+            @Override
             public void accept(String t) {
                 System.out.println(t);
             }
@@ -229,25 +231,23 @@ abstract public class TestFmwk extends AbstractTestLog {
     // Utility Methods
 
     protected static String hex(char[] s){
-        StringBuffer result = new StringBuffer();
+        StringJoiner result = new StringJoiner(",");
         for (int i = 0; i < s.length; ++i) {
-            if (i != 0) result.append(',');
-            result.append(hex(s[i]));
+            result.add(hex(s[i]));
         }
         return result.toString();
     }
 
     protected static String hex(byte[] s){
-        StringBuffer result = new StringBuffer();
+        StringJoiner result = new StringJoiner(",");
         for (int i = 0; i < s.length; ++i) {
-            if (i != 0) result.append(',');
-            result.append(hex(s[i]));
+            result.add(hex(s[i]));
         }
         return result.toString();
     }
 
     protected static String hex(char ch) {
-        StringBuffer result = new StringBuffer();
+        StringBuilder result = new StringBuilder();
         String foo = Integer.toString(ch, 16).toUpperCase();
         for (int i = foo.length(); i < 4; ++i) {
             result.append('0');
@@ -256,7 +256,7 @@ abstract public class TestFmwk extends AbstractTestLog {
     }
 
     protected static String hex(int ch) {
-        StringBuffer result = new StringBuffer();
+        StringBuilder result = new StringBuilder();
         String foo = Integer.toString(ch, 16).toUpperCase();
         for (int i = foo.length(); i < 4; ++i) {
             result.append('0');
@@ -265,11 +265,9 @@ abstract public class TestFmwk extends AbstractTestLog {
     }
 
     protected static String hex(CharSequence s) {
-        StringBuilder result = new StringBuilder();
+        StringJoiner result = new StringJoiner(",");
         for (int i = 0; i < s.length(); ++i) {
-            if (i != 0)
-                result.append(',');
-            result.append(hex(s.charAt(i)));
+            result.add(hex(s.charAt(i)));
         }
         return result.toString();
     }
@@ -440,7 +438,7 @@ abstract public class TestFmwk extends AbstractTestLog {
             return -1;
         }
         int i = 0;
-        StringBuffer buf = new StringBuffer();
+        StringBuilder buf = new StringBuilder();
         int seenMask = 0;
         for (; i < array.length; ++i) {
             String s = array[i];
